<?php
// $Id: lastfmsimple.admin.inc,v 1.2.2.2 2009/04/07 21:22:10 mikereem Exp $
/**
 * @file
 * All functions related to the lastfmsimple adminstration
 */

/**
 * Generates the Last.fm Sipmle Stats admininistration form located at
 * ?q=admin/settings/lastfmsimple.
 */
function lastfmsimple_admin_settings() {
  // Get fields from the profile.module of the type 'textfield'.
  $options = _lastfmsimple_get_textfield_fields();

  // If there aren't any 'textfield' fields, throw an error and return an empty form
  if (empty($options)) {
    drupal_set_message(t('No profile fields of type \'textfield\' were found, please <a href="@profile-settings-page">create one here</a>.', array('@profile-settings-page' => url('admin/user/profile/add/textfield'))), 'error');
    return;
  }

  $options = array('') + $options;
  // Fieldset for general settings
  $form['lastfmsimple_general_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['lastfmsimple_general_settings']['lastfmsimple_username_field_id'] = array(
    '#type' => 'select',
    '#title' => t('Profile username field'),
    '#default_value' => variable_get('lastfmsimple_username_field_id', NULL),
    '#description' => t("Select which profile field of type 'textfield' you want to use as Last.fm username."),
    '#options' => $options,
    '#required' => TRUE,
  );
  
  $form['lastfmsimple_general_settings']['lastfmsimple_groupname_field_id'] = array(
    '#type' => 'select',
    '#title' => t('Profile groupname field'),
    '#default_value' => variable_get('lastfmsimple_groupname_field_id', NULL),
    '#description' => t("Select which profile field of type 'textfield' you want to use as Last.fm groupname."),
    '#options' => $options,
    '#required' => TRUE,
  );
  
  // Fieldset for update settings
  $form['lastfmsimple_update_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Update settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
	
  $form['lastfmsimple_update_settings']['lastfmsimple_interval'] = array(
    '#type' => 'select',
      '#title' => t('Update interval'),
      '#description' => t('Select the interval fetched data should be updated by cron. Every feed is cached for one week, except the Recent tracks, which will be fetched at every update. Be careful with this interval, updating can take minutes. For details see the README!'),
      '#options' => array(
	5 => t('@minutes minutes', array('@minutes' => 5)),
	15 => t('@minutes minutes', array('@minutes' => 15)),
	30 => t('@minutes minutes', array('@minutes' => 30)),
	60 => t('Hourly'),
	120 => t('@hours hours', array('@hours' => 2)),
	180 => t('@hours hours', array('@hours' => 3)),
	360 => t('@hours hours', array('@hours' => 6)),
	720 => t('@hours hours', array('@hours' => 12)),
	1440 => t('Daily'),
	),
      '#default_value' => variable_get('lastfmsimple_interval', 5),
      '#required' => TRUE,
	);

  // Fieldset for the lastfmsimple block.
  $form['lastfmsimple_block'] = array(
    '#type' => 'fieldset',
    '#title' => t('Last.fm Simple Stats block settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  
  $form['lastfmsimple_block']['lastfmsimple_block_display'] = array(
  	'#type' => 'radios',
  	'#title' => t('Display type'),
  	'#description' => t('Select the block display type. If you want to use the flash displayer, you will need the lastfmsimple.swf which is not included by default. Check README.txt for more info.'),
  	'#options' => array(
  	LASTFMSIMPLE_FLASH_OFF => t('Normal'),
  	LASTFMSIMPLE_FLASH_ON => t('Flash')
  	),
  	'#default_value' => variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT),
  	'#required' => TRUE
  	);

  $form['lastfmsimple_block']['lastfmsimple_statline_display'] = array(
    '#type' => 'radios',
      '#title' => t('Display of stats'),
      '#description' => t('Choose the display type of the lines of statistics.'),
      '#options' => array(
	LASTFMSIMPLE_STATLINE_LINK => t('Link to Last.fm'),
	LASTFMSIMPLE_STATLINE_TEXT => t('Plain text'),
	),
      '#default_value' => variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT),
      '#required' => TRUE,
	);
  
  $form['lastfmsimple_block']['lastfmsimple_block_feedtype'] = array(
    '#type' => 'radios',
      '#title' => t('Feed type'),
      '#description' => t('Select the feed type which you want to use in the block.'),
      '#options' => array(
	LASTFMSIMPLE_BLOCK_FEED_TYPE_USER => t('User feeds'),
	LASTFMSIMPLE_BLOCK_FEED_TYPE_GROUP => t('Group feeds'),
	LASTFMSIMPLE_BLOCK_FEED_TYPE_INSITE => t('In-site')
	),
      '#default_value' => variable_get('lastfmsimple_block_feedtype', LASTFMSIMPLE_BLOCK_FEED_TYPE_DEFAULT),
      '#required' => TRUE,
  );
  
  $form['lastfmsimple_block']['lastfmsimple_block_length'] = array(
    '#type' => 'textfield',
      '#title' => t('Feed length'),
      '#description' => t('Set the number of records you want to show in the block.'),
  	  '#size' => 3,
  	  '#maxlength' => 3,
      '#default_value' => variable_get('lastfmsimple_block_length', 10),
      '#required' => TRUE,
  );

  $form['lastfmsimple_block']['lastfmsimple_block_userfeedtype'] = array(
    '#type' => 'select',
    '#title' => t('Set Last.fm Simple Stats block user statistic type'),
    '#default_value' => variable_get('lastfmsimple_block_userfeedtype', LASTFMSIMPLE_BLOCK_STAT_USER_DEFAULT),
    '#description' => t("Select the user statistic type you want to show on the block if user feeds selected."),
    '#options' => array(
	  LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYALBUMCHART => t('Weekly album chart'),
      LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYARTISTCHART => t('Weekly artist chart'),
      LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYTRACKCHART => t('Weekly track chart'),
      LASTFMSIMPLE_BLOCK_STAT_USER_RECENTTRACKS => t('Recent tracks'),
      LASTFMSIMPLE_BLOCK_STAT_USER_TOPALBUMS => t('Top albums'),
      LASTFMSIMPLE_BLOCK_STAT_USER_TOPARTISTS => t('Top artists'),
      LASTFMSIMPLE_BLOCK_STAT_USER_TOPTAGS => t('Top tags'),
      LASTFMSIMPLE_BLOCK_STAT_USER_TOPTRACKS => t('Top tracks'),
      LASTFMSIMPLE_BLOCK_STAT_USER_LOVEDTRACKS => t('Loved tracks'),
      LASTFMSIMPLE_BLOCK_STAT_USER_FRIENDS => t('Friends')
    ),
    '#required' => FALSE,
  );
  
  $form['lastfmsimple_block']['lastfmsimple_block_groupfeedtype'] = array(
    '#type' => 'select',
    '#title' => t('Set Last.fm Simple Stats block group statistic type'),
    '#default_value' => variable_get('lastfmsimple_block_groupfeedtype', LASTFMSIMPLE_BLOCK_STAT_GROUP_DEFAULT),
    '#description' => t("Select the group statistic type you want to show on the block if group feeds selected."),
    '#options' => array(
	  LASTFMSIMPLE_BLOCK_STAT_GROUP_WEEKLYALBUMCHART => t('Weekly album chart'),
      LASTFMSIMPLE_BLOCK_STAT_GROUP_WEEKLYARTISTCHART => t('Weekly artist chart'),
      LASTFMSIMPLE_BLOCK_STAT_GROUP_WEEKLYTRACKCHART => t('Weekly track chart'),
      LASTFMSIMPLE_BLOCK_STAT_GROUP_MEMBERS => t('Members')
    ),
    '#required' => FALSE,
  );
  
  $form['lastfmsimple_block']['lastfmsimple_block_insitefeedtype'] = array(
    '#type' => 'select',
    '#title' => t('Set Last.fm Simple Stats block in-site statistic type'),
    '#default_value' => variable_get('lastfmsimple_block_insitefeedtype', LASTFMSIMPLE_BLOCK_STAT_GROUP_DEFAULT),
    '#description' => t("Select the in-site statistic type you want to show on the block if in-site selected."),
    '#options' => array(
      LASTFMSIMPLE_BLOCK_STAT_INSITE_COMPARE => t('Neighbours'),
      LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMEALBUMS => t('Same albums'),
      LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMEARTISTS => t('Same artists'),
      LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMETRACKS => t('Same tracks')
    ),
    '#required' => FALSE,
  );

  return system_settings_form($form);
}