<?php
// $Id: lastfmsimple.insite.inc,v 1.1.2.1 2009/04/07 21:22:10 mikereem Exp $
/*
 * @file
 * All functions related to in-site statistics.
 */

define('LASTFMSIMPLE_LASTFMUSERURL', "http://www.last.fm/user/");

/**
 * Update an existing feed in lastfmsimple_compare.
 *
 * @param $feed
 *   The feed object.
 */
function _lastfmsimple_update_feedcompare(&$feed) {
	$request = _lastfmsimple_fetch_feedcompare($feed->name1, $feed->name2, $feed->modified);
	
	if ($request === FALSE) {
		return;
	}

	// Remove existing items.
	db_query("DELETE FROM {lastfmsimple_compare} WHERE iid = %d", $feed->iid);

	// Parse the feed data.
	_lastfmsimple_parse_feedcompare($request['data'], $feed->iid, $feed->name1, $feed->name2, $request['element']);

	// Update the feed's row.
	db_query("UPDATE {lastfmsimple_compare} SET updated = %d, modified = %d, expires = %d WHERE iid = %d", time(), $request['headers']['Last-Modified'], $request['headers']['Expires'], $feed->iid);
}

/** Fetch the compare feed.
 *
 * @param $user1
 *   A string containing the Last.fm user name1.
 * @param $user2
 *   A string containing the Last.fm user name2.
 * @param $modified_since
 *   UNIX timestamp containing Modified-Since date (optional).
 * @return
 *   Array containing data, array of headers, not_modified boolean, element name.
 */
function _lastfmsimple_fetch_feedcompare($user1, $user2, $modified_since = 0) {
	// Use an If-Modified-Since header when possible.
	$headers = $modified_since > 0 ? array('If-Modified-Since' => gmdate('D, d M Y H:i:s', $modified_since)) : array();

	// Do a HTTP request.
	$request = drupal_http_request('http://ws.audioscrobbler.com/2.0/?method=tasteometer.compare&type1=user&type2=user&value1=' . urlencode($user1) . '&value2=' . urlencode($user2) . '&api_key=' . LASTFMSIMPLE_API_KEY, $headers);
	
	// Response code.
	$code = (int) $request->code;

	// Something went wrong.
	if (!in_array($code, array(200, 302, 304, 307))) {
		watchdog('lastfmsimple', 'Tasteometer feed for user %user1 and %user2 could not be fetched: %error.', array(
      '%user1' => $user1,
      '%user2' => $user2,
      '%error' => $request->code .' '. $request->error
		), WATCHDOG_WARNING);

		return FALSE;
	}

	// What's the item's element?
    $element = 'score';

    $expires = time() + LASTFMSIMPLE_EXPIRE_TIME; 

    return array(
    'data' => $request->data,
    'headers' => array(
      'Last-Modified' => array_key_exists('Last-Modified', $request->headers) ? strtotime($request->headers['Last-Modified']) : 0,
    // Do not use Expires when it's in the past.
      'Expires' => $expires > time() ? $expires : 0,
    ),
    // Feed was not modified when we got response code 304.
    'not_modified' => ($code === 304),
    'element' => $element
    );
}

/**
 * Parse compare feed's data.
 *
 * @param $data
 *   String of feed data.
 * @param $id
 *   Item ID.
 * @param $name1
 * 	 User name1.
 * @param $name2
 *   User name2.
 * @param $element
 *   String containing item's element name.
 */
function _lastfmsimple_parse_feedcompare(&$data, $id, $name1, $name2, $element) {
	// Create the parser and get the object.
	$parser = new DOMDocument();
	$parser->loadXML($data);
	
	$node = $parser->getElementsByTagName($element);
	$score = $node->item(0)->nodeValue;
	// Insert new feed item.
	db_query("INSERT INTO {lastfmsimple_compare} (iid, name1, name2, updated, modified, expires, item_data) VALUES (%d, '%s', '%s', %d, %d, %d, %f)", $id, $name1, $name2, 0, 0, 0, $score);
}

/**
 * Update an existing feed.
 *
 * @param $feed
 *   The feed name.
 * @param $count
 *   Optional integer value for item number.
 */
function _lastfmsimple_update_feed_insite($feedname, $count = 10) {
	$result = db_query("SELECT * FROM {lastfmsimple_feed} WHERE (feed_type = '%s') AND (updated <= %d)", $feedname, (time() - $interval * 60));
	switch ($feedname) {
		case LASTFMSIMPLE_BLOCK_FEED_TYPE_INSITE . LASTFMSIMPLE_BLOCK_STAT_INSITE_COMPARE:
			while ($feed = db_fetch_object($result)) {
				_lastfmsimple_update_neighbours($feed, $count);
			}
		case LASTFMSIMPLE_BLOCK_FEED_TYPE_INSITE . LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMEALBUMS:
		    while ($feed = db_fetch_object($result)) {
		        _lastfmsimple_update_samealbums($feed, $count);
		    }
	    case LASTFMSIMPLE_BLOCK_FEED_TYPE_INSITE . LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMEARTISTS:
		    while ($feed = db_fetch_object($result)) {
		        _lastfmsimple_update_sameartists($feed, $count);
		    }
	    case LASTFMSIMPLE_BLOCK_FEED_TYPE_INSITE . LASTFMSIMPLE_BLOCK_STAT_INSITE_SAMETRACKS:
		    while ($feed = db_fetch_object($result)) {
		        _lastfmsimple_update_sametracks($feed, $count);
		    }
	}
}

/**
 * Calculate and update the neighbours values.
 *
 * @param object $feed
 * 	 The feed object.
 * @param int $count
 *   Integer value for item number.
 */
function _lastfmsimple_update_neighbours(&$feed, $count) {
	global $user;
	global $_lastfmsimple_username_field;
	global $base_path;
	
	// Remove existing items.
	db_query("DELETE FROM {lastfmsimple_item} WHERE fid = %d", $feed->fid);
	
	// Get the list of other users.
	$resultothers = db_query("SELECT value FROM {profile_values} WHERE value <> '%s' AND fid = %d", $feed->usr, variable_get('lastfmsimple_username_field_id', NULL));
	
	// Iterate through all of the users and check their tasteometer score. If it doesn't exist, create it.
	$compared = array();
	while ($othername = db_fetch_object($resultothers)) {
		$resultcompare = db_query("SELECT item_data FROM {lastfmsimple_compare} WHERE (name1 = '%s' AND name2 = '%s') OR (name1 = '%s' AND name2 = '%s')", $feed->usr, $othername->value, $othername->value, $feed->usr);
		if (($compare = db_fetch_object($resultcompare)) == NULL) {
			// The two user hasn't been compared yet. Add them to the lastfmsimple_compare table and the next cron update will get their score.
			$score = 0;
			db_query("INSERT INTO {lastfmsimple_compare} (name1, name2, updated, modified, expires, item_data) VALUES ('%s', '%s', %d, %d, %d, %f)", $feed->usr, $othername->value, 0, 0, 0, $score); 
		} else {
			$score = $compare->item_data;
		}
		$compared[$othername->value] = $score;
	}
	
	// Sort the list
	arsort($compared);
	// Save them
	$recordcounter = 0;
	do {
		$lastfmname = key($compared);
		$item_data = current($compared);
		$resultuids = db_query("SELECT uid FROM {profile_values} WHERE value = '%s'", $lastfmname);
		while ($uid = db_fetch_object($resultuids)) {
			$resultusername = db_query("SELECT name FROM {users} WHERE uid = %d", $uid->uid);
			$name = db_fetch_object($resultusername);
			$url = url(LASTFMSIMPLE_LASTFMUSERURL . $lastfmname);
			// Insert new feed item.
			if ($recordcounter == $count) {
				break;
			} else {
				db_query("INSERT INTO {lastfmsimple_item} (fid, name, url, item_data) VALUES (%d, '%s', '%s', '%s')", $feed->fid, $name->name, $url, $item_data);
				$recordcounter++;
			}
		}
		if ($recordcounter == $count) {
    		break;
    	}
	} while (next($compared));
	// Update the feed's row.
	db_query("UPDATE {lastfmsimple_feed} SET updated = %d, modified = %d, expires = %d, current_count = %d, max_count = %d, fetches = fetches + 1, updates = updates + 1 WHERE fid = %d", time(), 0, 0, $count, count($compared), $feed->fid);
}

/**
 * Calculate and update the same albums values.
 *
 * @param object $feed
 * 	 The feed object.
 * @param int $count
 *   Integer value for item number.
 */
function _lastfmsimple_update_samealbums(&$feed, $count) {
	global $user;
	global $_lastfmsimple_username_field;
	global $base_path;
	
	// Remove existing items.
	db_query("DELETE FROM {lastfmsimple_item} WHERE fid = %d", $feed->fid);
	
	// Get the list of Weekly Albums feed id's for all users.
	$resultweeklyalbumsfeed = db_query("SELECT usr, fid FROM {lastfmsimple_feed} WHERE feed_type = '%s'", LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYALBUMCHART);
	$weeklyalbumsfeeds = array();
	while ($weeklyalbumsfeed = db_fetch_object($resultweeklyalbumsfeed)) {
		$weeklyalbumsfeeds[$weeklyalbumsfeed->usr] = $weeklyalbumsfeed->fid;
	}
	
	// Get the Weekly Albums of this user.
	$resultweeklyalbums = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklyalbumsfeeds[$feed->usr]);
	$thisweeklyalbums = array();
	while ($thisweeklyalbum = db_fetch_object($resultweeklyalbums)) {
		$thisweeklyalbums[] = $thisweeklyalbum;
	}
	
	// Get the list of other users.
	$resultothers = db_query("SELECT value FROM {profile_values} WHERE value <> '%s' AND fid = %d", $feed->usr, variable_get('lastfmsimple_username_field_id', NULL));
	
	// Iterate through all of the users, and compare them whith the actual user.
	$compared = array();
	while ($othername = db_fetch_object($resultothers)) {
	    // If the feed id doesn't exist for the user, then create it (that user didn't logged in since this feed was turned on, but we need his stats).
	    if ($weeklyalbumsfeeds[$othername->value] == NULL) {
	        _lastfmsimple_new_feed($othername->value, LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYALBUMCHART, LASTFMSIMPLE_INSITE_FEED_COUNT);
		// Else continue with the comparison	
	    } else {
    		$resultweeklyalbums = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklyalbumsfeeds[$othername->value]);
    		$otherweeklyalbums = array();
    		while ($otherweeklyalbum = db_fetch_object($resultweeklyalbums)) {
    			$otherweeklyalbums[] = $otherweeklyalbum;
    		}
    	
    		// The comparison
    		$value = 0;
    		foreach ($thisweeklyalbums as $thisweeklyalbum):
    			if (in_array($thisweeklyalbum, $otherweeklyalbums)) {
    				$value += 1;
    			}
    		endforeach;
    		$compared[$othername->value] = $value;
	    }
	}
	
	// Sort the list
	arsort($compared);
	// Save them
	$recordcounter = 0;
	do {
		$lastfmname = key($compared);
		$item_data = current($compared);
		$resultuids = db_query("SELECT uid FROM {profile_values} WHERE value = '%s'", $lastfmname);
		while ($uid = db_fetch_object($resultuids)) {
			$resultusername = db_query("SELECT name FROM {users} WHERE uid = %d", $uid->uid);
			$name = db_fetch_object($resultusername);
			$url = url(LASTFMSIMPLE_LASTFMUSERURL . $lastfmname);
			// Insert new feed item.
			if ($recordcounter == $count) {
				break;
			} else if ($item_data != 0) {
				db_query("INSERT INTO {lastfmsimple_item} (fid, name, url, item_data) VALUES (%d, '%s', '%s', '%s')", $feed->fid, $name->name, $url, $item_data);
				$recordcounter++;
			}
		}
		if ($recordcounter == $count) {
    		break;
    	}
	} while (next($compared));
	// Update the feed's row.
	db_query("UPDATE {lastfmsimple_feed} SET updated = %d, modified = %d, expires = %d, current_count = %d, max_count = %d, fetches = fetches + 1, updates = updates + 1 WHERE fid = %d", time(), 0, 0, $count, count($compared), $feed->fid);
}

/**
 * Calculate and update the same artists values.
 *
 * @param object $feed
 * 	 The feed object.
 * @param int $count
 *   Integer value for item number.
 */
function _lastfmsimple_update_sameartists(&$feed, $count) {
	global $user;
	global $_lastfmsimple_username_field;
	global $base_path;
	
	// Remove existing items.
	db_query("DELETE FROM {lastfmsimple_item} WHERE fid = %d", $feed->fid);
	
	// Get the list of Weekly Artists feed id's for all users.
	$resultweeklyartistsfeed = db_query("SELECT usr, fid FROM {lastfmsimple_feed} WHERE feed_type = '%s'", LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYARTISTCHART);
	$weeklyartistsfeeds = array();
	while ($weeklyartistsfeed = db_fetch_object($resultweeklyartistsfeed)) {
		$weeklyartistsfeeds[$weeklyartistsfeed->usr] = $weeklyartistsfeed->fid;
	}
	
	// Get the Weekly Artists of this user.
	$resultweeklyartists = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklyartistsfeeds[$feed->usr]);
	$thisweeklyartists = array();
	while ($thisweeklyartist = db_fetch_object($resultweeklyartists)) {
		$thisweeklyartists[] = $thisweeklyartist;
	}
	
	// Get the list of other users.
	$resultothers = db_query("SELECT value FROM {profile_values} WHERE value <> '%s' AND fid = %d", $feed->usr, variable_get('lastfmsimple_username_field_id', NULL));
	
	// Iterate through all of the users, and compare them whith the actual user.
	$compared = array();
	while ($othername = db_fetch_object($resultothers)) {
	    // If the feed id doesn't exist for the user, then create it (that user didn't logged in since this feed was turned on, but we need his stats).
	    if ($weeklyartistsfeeds[$othername->value] == NULL) {
	        _lastfmsimple_new_feed($othername->value, LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYARTISTCHART, LASTFMSIMPLE_INSITE_FEED_COUNT);
		// Else continue with the comparison	
	    } else {
    		$resultweeklyartists = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklyartistsfeeds[$othername->value]);
    		$otherweeklyartists = array();
    		while ($otherweeklyartist = db_fetch_object($resultweeklyartists)) {
    			$otherweeklyartists[] = $otherweeklyartist;
    		}
    	
    		// The comparison
    		$value = 0;
    		foreach ($thisweeklyartists as $thisweeklyartist):
    			if (in_array($thisweeklyartist, $otherweeklyartists)) {
    				$value += 1;
    			}
    		endforeach;
    		$compared[$othername->value] = $value;
	    }
	}
	
	// Sort the list
	arsort($compared);
	// Save them
	$recordcounter = 0;
	do {
		$lastfmname = key($compared);
		$item_data = current($compared);
		$resultuids = db_query("SELECT uid FROM {profile_values} WHERE value = '%s'", $lastfmname);
		while ($uid = db_fetch_object($resultuids)) {
			$resultusername = db_query("SELECT name FROM {users} WHERE uid = %d", $uid->uid);
			$name = db_fetch_object($resultusername);
			$url = url(LASTFMSIMPLE_LASTFMUSERURL . $lastfmname);
			// Insert new feed item.
			if ($recordcounter == $count) {
				break;
			} else if ($item_data != 0) {
				db_query("INSERT INTO {lastfmsimple_item} (fid, name, url, item_data) VALUES (%d, '%s', '%s', '%s')", $feed->fid, $name->name, $url, $item_data);
				$recordcounter++;
			}
		}
		if ($recordcounter == $count) {
    		break;
    	}
	} while (next($compared));
	// Update the feed's row.
	db_query("UPDATE {lastfmsimple_feed} SET updated = %d, modified = %d, expires = %d, current_count = %d, max_count = %d, fetches = fetches + 1, updates = updates + 1 WHERE fid = %d", time(), 0, 0, $count, count($compared), $feed->fid);
}

/**
 * Calculate and update the same tracks values.
 *
 * @param object $feed
 * 	 The feed object.
 * @param int $count
 *   Integer value for item number.
 */
function _lastfmsimple_update_sametracks(&$feed, $count) {
	global $user;
	global $_lastfmsimple_username_field;
	global $base_path;
	
	// Remove existing items.
	db_query("DELETE FROM {lastfmsimple_item} WHERE fid = %d", $feed->fid);
	
	// Get the list of Weekly Tracks feed id's for all users.
	$resultweeklytracksfeed = db_query("SELECT usr, fid FROM {lastfmsimple_feed} WHERE feed_type = '%s'", LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYTRACKCHART);
	$weeklytracksfeeds = array();
	while ($weeklytracksfeed = db_fetch_object($resultweeklytracksfeed)) {
		$weeklytracksfeeds[$weeklytracksfeed->usr] = $weeklytracksfeed->fid;
	}
	
	// Get the Weekly Tracks of this user.
	$resultweeklytracks = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklytracksfeeds[$feed->usr]);
	$thisweeklytracks = array();
	while ($thisweeklytrack = db_fetch_object($resultweeklytracks)) {
		$thisweeklytracks[] = $thisweeklytrack;
	}
	
	// Get the list of other users.
	$resultothers = db_query("SELECT value FROM {profile_values} WHERE value <> '%s' AND fid = %d", $feed->usr, variable_get('lastfmsimple_username_field_id', NULL));
	
	// Iterate through all of the users, and compare them whith the actual user.
	$compared = array();
	while ($othername = db_fetch_object($resultothers)) {
	    // If the feed id doesn't exist for the user, then create it (that user didn't logged in since this feed was turned on, but we need his stats).
	    if ($weeklytracksfeeds[$othername->value] == NULL) {
	        _lastfmsimple_new_feed($othername->value, LASTFMSIMPLE_BLOCK_FEED_TYPE_USER . LASTFMSIMPLE_BLOCK_STAT_USER_WEEKLYTRACKCHART, LASTFMSIMPLE_INSITE_FEED_COUNT);
		// Else continue with the comparison	
	    } else {
    		$resultweeklytracks = db_query("SELECT name FROM {lastfmsimple_item} WHERE fid = %d ORDER BY iid ASC", $weeklytracksfeeds[$othername->value]);
    		$otherweeklytracks = array();
    		while ($otherweeklytrack = db_fetch_object($resultweeklytracks)) {
    			$otherweeklytracks[] = $otherweeklytrack;
    		}
    	
    		// The comparison
    		$value = 0;
    		foreach ($thisweeklytracks as $thisweeklytrack):
    			if (in_array($thisweeklytrack, $otherweeklytracks)) {
    				$value += 1;
    			}
    		endforeach;
    		$compared[$othername->value] = $value;
	    }
	}
	
	// Sort the list
	arsort($compared);
	// Save them
	$recordcounter = 0;
	do {
		$lastfmname = key($compared);
		$item_data = current($compared);
		$resultuids = db_query("SELECT uid FROM {profile_values} WHERE value = '%s'", $lastfmname);
		while ($uid = db_fetch_object($resultuids)) {
			$resultusername = db_query("SELECT name FROM {users} WHERE uid = %d", $uid->uid);
			$name = db_fetch_object($resultusername);
			$url = url(LASTFMSIMPLE_LASTFMUSERURL . $lastfmname);
			// Insert new feed item.
			if ($recordcounter == $count) {
				break;
			} else if ($item_data != 0) {
				db_query("INSERT INTO {lastfmsimple_item} (fid, name, url, item_data) VALUES (%d, '%s', '%s', '%s')", $feed->fid, $name->name, $url, $item_data);
				$recordcounter++;
			}
		}
		if ($recordcounter == $count) {
    		break;
    	}
	} while (next($compared));
	// Update the feed's row.
	db_query("UPDATE {lastfmsimple_feed} SET updated = %d, modified = %d, expires = %d, current_count = %d, max_count = %d, fetches = fetches + 1, updates = updates + 1 WHERE fid = %d", time(), 0, 0, $count, count($compared), $feed->fid);
}