<?php
// $Id: lastfmsimple.showfeeds.inc,v 1.1.2.1 2009/04/07 21:22:10 mikereem Exp $
/*
 * @file
 * All functions related to displaying the feeds.
 */

/**
 * Create block content for recenttracks stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user. 
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_recenttracks($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Recent tracks of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Recent tracks of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="' . $item->url . '">' . $artist . ' - ' . $item->name . '</a></li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . '</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Recent tracks of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Recent tracks of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name;
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for weeklyalbumchart stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username or groupname of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_weeklyalbumchart($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly albums of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Weekly albums of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->nodeValue;
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="' . $item->url . '">' . $artist . ' - ' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly albums of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Weekly albums of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->nodeValue;
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for weeklyartistchart stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username or groupname of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_weeklyartistchart($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly artists of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Weekly artists of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly artists of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Weekly artists of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for weeklytrackchart stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username or groupname of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_weeklytrackchart($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly tracks of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Weekly tracks of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $artist . ' - ' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Weekly tracks of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Weekly tracks of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for topalbums stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_topalbums($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top albums of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Top albums of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $artist . ' - ' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top albums of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Top albums of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for topartists stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_topartists($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top artists of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Top artists of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top artists of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Top artists of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}	
	return $block_content;
}

/**
 * Create block content for top tags stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_toptags($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top tags of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Top tags of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$counts = $value->getElementsByTagName("count");
				$count = $counts->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $count . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $count . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top tags of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Top tags of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name;
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}	
	return $block_content;
}

/**
 * Create block content for toptracks stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_toptracks($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top tracks of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Top tracks of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$playcounts = $value->getElementsByTagName("playcount");
				$playcount = $playcounts->item(0)->nodeValue;
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $artist . ' - ' . $item->name . '</a> (' . $playcount . ')</li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . ' (' . $playcount . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Top tracks of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Top tracks of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$playcounts = $value->getElementsByTagName("playcount");
					$playcount = $playcounts->item(0)->nodeValue;
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name . ' (' . $playcount . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for lovedtracks stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_lovedtracks($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Loved tracks of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Loved tracks of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$artists = $value->getElementsByTagName("artist");
				$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $artist . ' - ' . $item->name . '</a></li>';
			} else {
				$block_content .= '<li>' . $artist . ' - ' . $item->name . '</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Loved tracks of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Loved tracks of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$value = new DOMDocument();
				$value->loadXML($item->item_data);
				if ($value != NULL) {
					$artists = $value->getElementsByTagName("artist");
					$artist = $artists->item(0)->getElementsByTagName("name")->item(0)->nodeValue;
				}
				$flashcontent[$cnt] = $artist . ' - ' . $item->name;
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for friends stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_friends($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Friends of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Friends of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$images = $value->getElementsByTagName("image");
				for ($i = 0; $i < $images->length; $i++) {
					if($images->item($i)->getAttribute("size") == "small") {
						$image = $images->item($i)->nodeValue;
						break;
					}
				}
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '"><img src="' . $image . '" align=top /></a> <a href="'. $item->url . '">' . $item->name . '</a></li>';
			} else {
				$block_content .= '<li><img src="' . $image . '" align=top /> ' . $item->name . '</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Friends of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Friends of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name;
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/**
 * Create block content for members stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm groupname of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_members($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Members of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Members of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			$value = new DOMDocument();
			$value->loadXML($item->item_data);
			if ($value != NULL) {
				$images = $value->getElementsByTagName("image");
				for ($i = 0; $i < $images->length; $i++) {
					if($images->item($i)->getAttribute("size") == "small") {
						$image = $images->item($i)->nodeValue;
						break;
					}
				}
			}
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '"><img src="' . $image . '" align=top /></a> <a href="'. $item->url . '">' . $item->name . '</a></li>';
			} else {
				$block_content .= '<li><img src="' . $image . '" align=top /> ' . $item->name . '</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Members of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Members of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name;
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/** Create block content for neighbours stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_neighbours($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Neighbours of %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Neighbours of %user:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . number_format($item->item_data*100, 2) . '%)</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . number_format($item->item_data*100, 2) . '%)</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('Neighbours of %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Neighbours of %user:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name . ' (' . number_format($item->item_data*100, 2) . '%)';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/** Create block content for same albums stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_samealbums($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same albums to %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Users %user share albums with in this week:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $item->item_data . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $item->item_data . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same albums to %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Users %user share albums with in this week:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name . ' (' . $item->item_data . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/** Create block content for same artists stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_sameartists($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same artists to %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Users %user share artists with in this week:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $item->item_data . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $item->item_data . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same artists to %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Users %user share artists with in this week:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name . ' (' . $item->item_data . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}
	return $block_content;
}

/** Create block content for same tracks stat.
 *
 * @param $content
 * Result of the feed query.
 * @param $user
 * Last.fm username of the current user.
 * @return unknown
 * Returns the formatted block content.
 */
function theme_lastfmsimple_show_sametracks($content, $user) {
	// setting up the block
	if (empty($content)) {
		return $block_content = '';
	} else if (variable_get('lastfmsimple_block_display', LASTFMSIMPLE_FLASH_DEFAULT) == LASTFMSIMPLE_FLASH_OFF) {
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same tracks to %user will be available soon.', array('%user' => $user));
			$block_content = '<hr />' . $header;
		} else {
			$statline = variable_get('lastfmsimple_statline_display', LASTFMSIMPLE_STATLINE_DEFAULT);
			$header = t('Users %user share tracks with in this week:', array('%user' => $user));
			$block_content = '<hr />' . $header;
			$block_content .= '<ol>';
			foreach ( $content as $item ):
			if ($statline == LASTFMSIMPLE_STATLINE_LINK) {
				$block_content .= '<li><a href="'. $item->url . '">' . $item->name . '</a> (' . $item->item_data . ')</li>';
			} else {
				$block_content .= '<li>' . $item->name . ' (' . $item->item_data . ')</li>';
			}
			endforeach;
			$block_content .= '</ol>';
		}
	} else { //flash version
		$cnt = 0;
		$flashcontent = array();
		if ($content == LASTFMSIMPLE_NOT_FETCHED) {
			$header = t('The users with same tracks to %user will be available soon.', array('%user' => $user));
		} else {
			$header = t('Users %user share tracks with in this week:', array('%user' => $user));
			foreach ( $content as $item ):
				$flashcontent[$cnt] = $item->name . ' (' . $item->item_data . ')';
				$cnt++;
			endforeach;
		}
		$block_content = array(
			'header' => $header,
			'content' => $flashcontent,
			'count' => $cnt
		);
	}	
	return $block_content;
}